# Define the kmod package name here.
%define kmod_name spec-sw
%define kmods_built spec.ko wr-nic.ko

%define tagversion 2014-02
%define packageversion %(echo %{tagversion} | sed 's/-/./g')

%define gitversion 0-geb9b9d0

%define sourceversion %(echo %{gitversion} | sed 's/-/./g')

%define fmc_ver 0.1

# If kversion isn't defined on the rpmbuild line, define it here.
%{!?kversion: %define kversion 3.10.0-693.el7.%{_target_cpu}}

Name:    %{kmod_name}-kmod
Version: 0.0
Release: %{packageversion}.%{sourceversion}.1%{?dist}
Group:   System Environment/Kernel
License: GPLv2
Summary: %{kmod_name} kernel module(s)
URL:     http://www.ohwr.org/projects/spec-sw/repository

BuildRequires: perl
BuildRequires: redhat-rpm-config
ExclusiveArch: x86_64

BuildRequires: git
BuildRequires: fmc-kmod-headers = %{fmc_ver}

# for docs
BuildRequires: emacs texinfo-tex

# Sources.
Source0:  %{kmod_name}-%{version}.tar.bz2
Source5:  GPL-v2.0.txt
Source10: kmodtool-%{kmod_name}-el7.sh

Patch1: spec-sw-fixupmakefile.patch
Patch2: spec-sw-fix-trans_start-usage.patch
Patch3: spec-sw-fix-doc-paragraphindent.patch

# Disable the building of the debug package(s).
%define debug_package %{nil}

%description
This package provides the %{kmod_name} kernel module(s).
It is built to depend upon the specific ABI provided by a range of releases
of the same variant of the Linux kernel and not on any one specific build.

%package headers
Summary: Kernel headers for %{kmod_name}

%description headers
Kernel headers for %{kmod_name}-kmod

%package tools
Summary: Userspace utilities for %{kmod_name}
Requires:	%{kmod_name}-kmod = %{version}
Requires:	etherbone-core

%description tools
SPEC tools for %{kmod_name}-kmod

# Magic hidden here.
%{expand:%(sh %{SOURCE10} rpmtemplate %{kmod_name} %{kversion} "")}

%prep
%setup -q -n %{kmod_name}-%{version}
for thiskmod in %{kmods_built}; do
    echo "override ${thiskmod} * weak-updates/%{kmod_name}" >> kmod-%{kmod_name}.conf
done

GIT_VERSION=$(git describe --dirty --long --tags)

cat << EOF > spec-sw-version-env
GIT_VERSION=${GIT_VERSION}
SPEC_SW_VERSION=${GIT_VERSION}
EOF

%patch1 -p1
%patch2 -p1
%patch3 -p1

%build
KSRC=%{_usrsrc}/kernels/%{kversion}
FMC_HEADERS='/usr/src/kmods/fmc-%{fmc_ver}'

source ${FMC_HEADERS}/fmc-version-env

%{__cp} ${FMC_HEADERS}/Module.symvers kernel/

pushd kernel
%{__make} LINUX="${KSRC}" FMC_BUS=${FMC_HEADERS} FMC_BUS_VERSION=${FMC_BUS_VERSION}
popd

# Cleanup the mappings
for line in $(cat kernel/modules.order); do
  kmod=$(basename ${line})
  echo "kernel/extra/${kmod}" >> kernel/spec-sw.order
done

awk '{print $1 "\t" $2 "\textra/fmc\t" $4}' kernel/Module.symvers > kernel/spec-sw.symvers


# Build application tools
pushd tools
%{__make} %{?_smp_mflags}
popd

# Build docs
pushd doc
%{__make} %{?_smp_mflags} || true
popd



%install
pushd tools
%{__make} install DESTDIR=%{buildroot} BINDIR=%{_sbindir} LIBDIR=%{_libdir}
popd
pushd binaries
%{__make} install DESTDIR=%{buildroot} FIRMDIR=/lib/firmware/fmc
popd
%{__install} -D doc/spec-sw.txt %{buildroot}%{_defaultdocdir}/spec-sw-%{version}/spec-sw.txt
if [[ -e doc/spec-sw.html ]]; then
    %{__install} doc/spec-sw.html %{buildroot}%{_defaultdocdir}/spec-sw-%{version}/spec-sw.html
fi
%{__install} doc/*.jpg %{buildroot}%{_defaultdocdir}/spec-sw-%{version}/

# Setup headers
%{__install} -d %{buildroot}%{_usrsrc}/kmods/%{kmod_name}-%{version}/linux
echo "%{tagversion}-%{gitversion}" > %{buildroot}%{_usrsrc}/kmods/%{kmod_name}-%{version}/version
%{__install} spec-sw-version-env %{buildroot}%{_usrsrc}/kmods/%{kmod_name}-%{version}/spec-sw-version-env

%{__install} kernel/spec-sw.order %{buildroot}%{_usrsrc}/kmods/%{kmod_name}-%{version}/modules.order
%{__install} kernel/spec-sw.symvers %{buildroot}%{_usrsrc}/kmods/%{kmod_name}-%{version}/Module.symvers
for filename in $(cd kernel ; find . -type f -name \*.h); do
    %{__install} -D kernel/${filename} %{buildroot}%{_usrsrc}/kmods/%{kmod_name}-%{version}/linux/${filename}
done

# Install infopage
%{__install} -d %{buildroot}%{_infodir}
if [[ -e doc/spec-sw.info ]]; then
    %{__install} doc/spec-sw.info %{buildroot}%{_infodir}/
else
    %{__install} doc/spec-sw.txt %{buildroot}%{_infodir}/spec-sw.info
fi

%{__install} -d %{buildroot}/lib/modules/%{kversion}/extra/%{kmod_name}/
for thiskmod in %{kmods_built}; do
    %{__install} kernel/${thiskmod} %{buildroot}/lib/modules/%{kversion}/extra/%{kmod_name}/
done
%{__install} -d %{buildroot}%{_sysconfdir}/depmod.d/
%{__install} kmod-%{kmod_name}.conf %{buildroot}%{_sysconfdir}/depmod.d/
%{__install} -d %{buildroot}%{_defaultdocdir}/kmod-%{kmod_name}-%{version}/
%{__install} %{SOURCE5} %{buildroot}%{_defaultdocdir}/kmod-%{kmod_name}-%{version}/

%{__install} kernel/spec-sw.order %{buildroot}%{_defaultdocdir}/kmod-%{kmod_name}-%{version}/modules.order
%{__install} kernel/spec-sw.symvers %{buildroot}%{_defaultdocdir}/kmod-%{kmod_name}-%{version}/Module.symvers


# strip the modules(s)
find %{buildroot} -type f -name \*.ko -exec %{__strip} --strip-debug \{\} \;

# Sign the modules(s)
%if %{?_with_modsign:1}%{!?_with_modsign:0}
# If the module signing keys are not defined, define them here.
%{!?privkey: %define privkey %{_sysconfdir}/pki/SECURE-BOOT-KEY.priv}
%{!?pubkey: %define pubkey %{_sysconfdir}/pki/SECURE-BOOT-KEY.der}
for module in $(find %{buildroot} -type f -name \*.ko);
do %{__perl} /usr/src/kernels/%{kversion}/scripts/sign-file \
sha256 %{privkey} %{pubkey} $module;
done
%endif

%clean
%{__rm} -rf %{buildroot}

%files tools
%defattr(0644,root,root,0755)
%docdir %{_defaultdocdir}/spec-sw-%{version}
%{_defaultdocdir}/spec-sw-%{version}/*
# management tools either make use of dev nodes with
#  group dialout, or outright calls to the kernel
%attr(4750, root, dialout) %{_sbindir}/*
%{_libdir}/*

%files headers
%defattr(0644,root,root,0755)
%{_usrsrc}/kmods/%{kmod_name}-%{version}


%changelog
* Tue Aug 29 2017 Akemi Yagi<toracat@elrepo.org> - 0.0-2014.02.0.geb9b9d0.1
- Initial el7 build of the kmod package
- Submitted by jcpunk [elrepo bug #688]
